@@ -44,7 +44,7 @@
 #include "pluginsettingspage.h"
 #include "pluginmanager.h"
 
-#include <KAboutData>
+#include <KPluginMetaData>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KGuiItem>
@@ -88,20 +88,27 @@ namespace Ark
 
 static quint32 s_instanceCounter = 1;
 
-Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList& args)
+Part::Part(QWidget *parentWidget, QObject *parent, const KPluginMetaData &metaData, const QVariantList& args)
         : KParts::ReadWritePart(parent),
           m_splitter(nullptr),
           m_busy(false),
           m_jobTracker(nullptr)
 {
     Q_UNUSED(args)
-    KAboutData aboutData(QStringLiteral("ark"),
-                         i18n("ArkPart"),
-                         QStringLiteral("3.0"));
-    setComponentData(aboutData, false);
+    setMetaData(metaData);
 
     new DndExtractAdaptor(this);
 
+    // Since QFileSystemWatcher::fileChanged is emitted for each part of the file that is flushed,
+    // we wait a bit to ensure that the last flush will write the file completely
+    // BUG: 382606, also see https://bugreports.qt.io/browse/QTBUG-8244
+    // TODO: Find the most optimal flush interval
+    m_watchedFileChangeTimer.setSingleShot(true);
+    m_watchedFileChangeTimer.setInterval(200);
+    connect(&m_watchedFileChangeTimer, &QTimer::timeout, this, [this]() {
+        slotWatchedFileModified(m_lastChangedFilename);
+    });
+
     const QString pathName = QStringLiteral("/DndExtract/%1").arg(s_instanceCounter++);
     if (!QDBusConnection::sessionBus().registerObject(pathName, this)) {
         qCCritical(ARK) << "Could not register a D-Bus object for drag'n'drop";
@@ -242,6 +249,16 @@ Part::~Part()
     m_extractAction->menu()->deleteLater();
 }
 
+QString Part::componentName() const
+{
+    // also the part ui.rc file is in the program folder
+    // TODO: change the component name to "arkpart" by removing this method and
+    // adapting the folder where the file is placed.
+    // Needs a way to also move any potential custom user ui.rc files
+    // from ark/ark_part.rc to arkpart/ark_part.rc
+    return QStringLiteral("ark");
+}
+
 void Part::slotCommentChanged()
 {
     if (!m_model->archive() || m_commentView->toPlainText().isEmpty()) {
@@ -385,20 +402,20 @@ void Part::setupActions()
     m_previewAction->setText(i18nc("to preview a file inside an archive", "Pre&view"));
     m_previewAction->setIcon(QIcon::fromTheme(QStringLiteral("document-preview-archive")));
     m_previewAction->setToolTip(i18nc("@info:tooltip", "Click to preview the selected file"));
-    actionCollection()->setDefaultShortcut(m_previewAction, Qt::CTRL + Qt::Key_P);
+    actionCollection()->setDefaultShortcut(m_previewAction, Qt::CTRL | Qt::Key_P);
     connect(m_previewAction, &QAction::triggered, this, [this]() { slotOpenEntry(Preview); });
 
     m_extractArchiveAction = actionCollection()->addAction(QStringLiteral("extract_all"));
     m_extractArchiveAction->setText(i18nc("@action:inmenu", "E&xtract All"));
     m_extractArchiveAction->setIcon(QIcon::fromTheme(QStringLiteral("archive-extract")));
     m_extractArchiveAction->setToolTip(i18n("Click to open an extraction dialog, where you can choose how to extract all the files in the archive"));
-    actionCollection()->setDefaultShortcut(m_extractArchiveAction, Qt::CTRL + Qt::SHIFT + Qt::Key_E);
+    actionCollection()->setDefaultShortcut(m_extractArchiveAction, Qt::CTRL | Qt::SHIFT | Qt::Key_E);
     connect(m_extractArchiveAction, &QAction::triggered, this, &Part::slotExtractArchive);
 
     m_extractAction = actionCollection()->addAction(QStringLiteral("extract"));
     m_extractAction->setText(i18nc("@action:inmenu", "&Extract"));
     m_extractAction->setIcon(QIcon::fromTheme(QStringLiteral("archive-extract")));
-    actionCollection()->setDefaultShortcut(m_extractAction, Qt::CTRL + Qt::Key_E);
+    actionCollection()->setDefaultShortcut(m_extractAction, Qt::CTRL | Qt::Key_E);
     m_extractAction->setToolTip(i18n("Click to open an extraction dialog, where you can choose to extract either all files or just the selected ones"));
     connect(m_extractAction, &QAction::triggered, this, &Part::slotShowExtractionDialog);
 
@@ -406,7 +423,7 @@ void Part::setupActions()
     m_addFilesAction->setIcon(QIcon::fromTheme(QStringLiteral("archive-insert")));
     m_addFilesAction->setText(i18n("Add &Files..."));
     m_addFilesAction->setToolTip(i18nc("@info:tooltip", "Click to add files to the archive"));
-    actionCollection()->setDefaultShortcut(m_addFilesAction, Qt::ALT + Qt::Key_A);
+    actionCollection()->setDefaultShortcut(m_addFilesAction, Qt::ALT | Qt::Key_A);
     connect(m_addFilesAction, &QAction::triggered, this, QOverload<>::of(&Part::slotAddFiles));
 
     m_renameFileAction = KStandardAction::renameFile(m_view, &ArchiveView::renameSelectedEntry, actionCollection());
@@ -422,20 +439,20 @@ void Part::setupActions()
     m_propertiesAction = actionCollection()->addAction(QStringLiteral("properties"));
     m_propertiesAction->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     m_propertiesAction->setText(i18nc("@action:inmenu", "&Properties"));
-    actionCollection()->setDefaultShortcut(m_propertiesAction, Qt::ALT + Qt::Key_Return);
+    actionCollection()->setDefaultShortcut(m_propertiesAction, Qt::ALT | Qt::Key_Return);
     m_propertiesAction->setToolTip(i18nc("@info:tooltip", "Click to see properties for archive"));
     connect(m_propertiesAction, &QAction::triggered, this, &Part::slotShowProperties);
 
     m_editCommentAction = actionCollection()->addAction(QStringLiteral("edit_comment"));
     m_editCommentAction->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
-    actionCollection()->setDefaultShortcut(m_editCommentAction, Qt::ALT + Qt::Key_C);
+    actionCollection()->setDefaultShortcut(m_editCommentAction, Qt::ALT | Qt::Key_C);
     m_editCommentAction->setToolTip(i18nc("@info:tooltip", "Click to add or edit comment"));
     connect(m_editCommentAction, &QAction::triggered, this, &Part::slotShowComment);
 
     m_testArchiveAction = actionCollection()->addAction(QStringLiteral("test_archive"));
     m_testArchiveAction->setIcon(QIcon::fromTheme(QStringLiteral("checkmark")));
     m_testArchiveAction->setText(i18nc("@action:inmenu", "&Test Integrity"));
-    actionCollection()->setDefaultShortcut(m_testArchiveAction, Qt::ALT + Qt::Key_T);
+    actionCollection()->setDefaultShortcut(m_testArchiveAction, Qt::ALT | Qt::Key_T);
     m_testArchiveAction->setToolTip(i18nc("@info:tooltip", "Click to test the archive for integrity"));
     connect(m_testArchiveAction, &QAction::triggered, this, &Part::slotTestArchive);
 
@@ -1029,8 +1046,9 @@ void Part::slotOpenExtractedEntry(KJob *job)
 
         const QString fullName = openJob->validatedFilePath();
         if (isArchiveWritable()) {
-            m_fileWatcher = new QFileSystemWatcher;
-            connect(m_fileWatcher, &QFileSystemWatcher::fileChanged, this, &Part::slotWatchedFileModified);
+            m_fileWatcher.reset(new QFileSystemWatcher);
+            connect(m_fileWatcher.get(), &QFileSystemWatcher::fileChanged, this, &Part::slotResetFileChangeTimer);
+
             m_fileWatcher->addPath(fullName);
         } else {
             // If archive is readonly set temporarily extracted file to readonly as
@@ -1072,6 +1090,22 @@ void Part::slotPreviewExtractedEntry(KJob *job)
     setReadyGui();
 }
 
+void Part::slotResetFileChangeTimer(const QString& file)
+{
+    const bool timerActive = m_watchedFileChangeTimer.isActive();
+    m_watchedFileChangeTimer.stop();
+    // Check if a different file was changed while monitoring the previous file.
+    if (timerActive && !m_lastChangedFilename.isEmpty() && file != m_lastChangedFilename) {
+        const QString prevFile = m_lastChangedFilename;
+        QTimer::singleShot(0, this, [this, prevFile]() {
+            slotWatchedFileModified(prevFile);
+        });
+    }
+
+    m_lastChangedFilename = file;
+    m_watchedFileChangeTimer.start();
+}
+
 void Part::slotWatchedFileModified(const QString& file)
 {
     qCDebug(ARK) << "Watched file modified:" << file;
@@ -1104,7 +1138,7 @@ void Part::slotWatchedFileModified(const QString& file)
         QStringList list = QStringList() << file;
 
         qCDebug(ARK) << "Updating file" << file << "with path" << relPath;
-        slotAddFiles(list, nullptr, relPath);
+        slotAddFiles(list, nullptr, relPath, DoNotShowOverwriteDialog);
     }
     // This is needed because some apps, such as Kate, delete and recreate
     // files when saving.
@@ -1286,7 +1320,7 @@ void Part::slotExtractionDone(KJob* job)
     }
 }
 
-void Part::slotAddFiles(const QStringList& filesToAdd, const Archive::Entry *destination, const QString &relPath)
+void Part::slotAddFiles(const QStringList& filesToAdd, const Archive::Entry *destination, const QString &relPath, OverwriteBehaviour onOverwrite)
 {
     if (!m_model->archive() || filesToAdd.isEmpty()) {
         return;
@@ -1314,7 +1348,7 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const Archive::Entry *des
     QList<const Archive::Entry*> conflictingEntries;
     bool error = m_model->conflictingEntries(conflictingEntries, withChildPaths, true);
 
-    if (conflictingEntries.count() > 0) {
+    if (onOverwrite == ShowOverwriteDialog && conflictingEntries.count() > 0) {
         QPointer<OverwriteDialog> overwriteDialog = new OverwriteDialog(widget(), conflictingEntries, error);
         int ret = overwriteDialog->exec();
         delete overwriteDialog;
